@@ -103,8 +103,8 @@ class powerswitch:
             result = urllib2.urlopen(request,timeout=self.timeout).read()
         except urllib2.URLError:
             return None
-        except timeout:
-            return None
+        #except timeout:
+        #    return None
         return result
     def off(self,outlet=0):
         """ Turn off a power to an outlet 
